{% extends 'base.html' %}
{% load bootstrap4 %}

{% block content %}

{% if validlink %}

<h1>Nouveau mot de passe</h1>

{% include 'ndh/form.html' %}

{% else %}

<h1>Échec.</h1>

<p>Ce lien est invalide, probablement parce qu’il a déjà été utilisé. Essaye encore!</p>

{% endif %}

{% endblock %}
